Sender

Struct Sender 

pub struct Sender<T> { /* private fields */ }
A broadcast sender that can be used with the postage::Sink trait. Can be cloned.

The sender task is suspended when the internal buffer is filled.

Note: no implementation of the futures::Sink trait is provided for the broadcast Sender.

Implementations

Source

impl<T> Sender<T>

pub fn subscribe(&self) -> Receiver<T>

Subscribes to the channel, creating a new receiver. The receiver will observe all messages sent after the call to subscribe.

Messages currently in the buffer are not received.