Context

Struct Context 

pub struct Context<'a> { /* private fields */ }
The Context of an asynchronous task.

Unlike std::task::Context, this context optionally contains a waker.

This is necessary because try_send and try_recv need to poll, but the task waker should not be saved if the try returns pending.

Implementations

Source

impl<'a> Context<'a>

pub fn from_waker(waker: &'a Waker) -> Self

Create a new Context from a &Waker.

pub fn empty() -> Self

Create an empty context with no waker.

pub fn waker(&self) -> Option<&'a Waker>

Returns an optional reference to the Waker for the current task.