pub struct Sender<T> { /* private fields */ }Expand description
A broadcast sender that can be used with the postage::Sink trait. Can be cloned.
The sender task is suspended when the internal buffer is filled.
Note: no implementation of the futures::Sink trait is provided for the broadcast Sender.
Implementations