pub struct Context<'a> { /* private fields */ }Expand description
The Context of an asynchronous task.
Unlike std::task::Context, this context optionally contains a waker.
This is necessary because try_send and try_recv need to poll, but the task waker should not be saved if the try returns pending.
Implementations